# Azure AI Search Document Store for Haystack

[![PyPI - Version](https://img.shields.io/pypi/v/azure-ai-search-haystack.svg)](https://pypi.org/project/azure-ai-search-haystack)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/azure-ai-search-haystack.svg)](https://pypi.org/project/azure-ai-search-haystack)

-----

**Table of Contents**

- [Azure AI Search Document Store for Haystack](#azure-ai-search-document-store-for-haystack)
  - [Installation](#installation)
  - [Examples](#examples)
  - [License](#license)

## Installation

```console
pip install azure-ai-search-haystack
```

## Examples
You can find a code example showing how to use the Document Store and the Retriever in the documentation or in [this Colab](https://colab.research.google.com/drive/1YpDetI8BRbObPDEVdfqUcwhEX9UUXP-m?usp=sharing).

## License

`azure-ai-search-haystack` is distributed under the terms of the [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html) license.
